@@ -61,6 +61,9 @@ class Status:
                     else:
                         self.father.framework.machine.task_state = False
 
+                    if not self.father.framework.package.handwheel.serial_status:
+                        self.father.framework.package.handwheel.init_serial()
+
                     self.father.framework.utils.service.service_write({"command": "launch:machine:info", "message": "", "data": self.father.framework.machine.info})
             self.father.framework.utils.set_sleep(0.05)
 
